summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMathieu Malaterre <mathieu.malaterre@gmail.com>2014-03-07 14:33:03 +0000
committerMathieu Malaterre <mathieu.malaterre@gmail.com>2014-03-07 14:33:03 +0000
commit440ef4873b079046b4c7d22694542779d0af70ac (patch)
tree6f763903d16c0e6e612b08633cab6891382d87f5
parentffad2fbe55d9df5cd51ba230a47d8a87b277be31 (diff)
[trunk] Also override the default error handler for TIFF files
-rw-r--r--tests/comparePGXimages.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/tests/comparePGXimages.c b/tests/comparePGXimages.c
index c6ccf488..978b9610 100644
--- a/tests/comparePGXimages.c
+++ b/tests/comparePGXimages.c
@@ -149,11 +149,13 @@ static opj_image_t* readImageFromFileTIF(const char* filename, int nbFilenamePGX
opj_image_cmptparm_t* param_image_read;
int** data;
/* conformance test suite produce annoying warning:
* TIFFReadDirectory: Warning, /.../data/baseline/conformance/jp2_1.tif: unknown field with tag 37724 (0x935c) encountered.
+ * TIFFOpen: /.../data/baseline/nonregression/opj_jp2_1.tif: Cannot open.
* On Win32 this open a message box by default, so remove it from the test suite:
*/
TIFFSetWarningHandler(NULL);
+ TIFFSetErrorHandler(NULL);
/* If separator is empty => nb file to read is equal to one*/
if ( strlen(separator) == 0 )
@@ -149,11 +149,13 @@ static opj_image_t* readImageFromFileTIF(const char* filename, int nbFilenamePGX
opj_image_cmptparm_t* param_image_read;
int** data;
- /* conformance test suite produce annoying warning:
+ /* conformance test suite produce annoying warning/error:
* TIFFReadDirectory: Warning, /.../data/baseline/conformance/jp2_1.tif: unknown field with tag 37724 (0x935c) encountered.